<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Gymnaz
 */

if ( ! function_exists( 'gymnaz_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function gymnaz_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( 'Posted on %s', 'post date', 'gymnaz-pro' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'gymnaz_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function gymnaz_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( 'by %s', 'post author', 'gymnaz-pro' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'gymnaz_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function gymnaz_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'gymnaz-pro' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'gymnaz-pro' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'gymnaz-pro' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'gymnaz-pro' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'gymnaz-pro' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'gymnaz-pro' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'gymnaz_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function gymnaz_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

			<div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
			</div><!-- .post-thumbnail -->

		<?php else : ?>

		<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
			<?php
			the_post_thumbnail( 'post-thumbnail', array(
				'alt' => the_title_attribute( array(
					'echo' => false,
				) ),
			) );
			?>
		</a>

		<?php
		endif; // End is_singular().
	}
endif;


/**
 * Set primary content class based on sidebar position
 * 
 * @param  string $sidebar_pos
 * @param  string $extra_class
 */
function gymnaz_primary_class( $sidebar_pos, $extra_class = '' ) {
    if ( is_page() ) :
        $sidebar_load = 'sidebar';
    else :
        $sidebar_load = 'sidebar';
    endif;

    if ( is_active_sidebar( $sidebar_load ) ) {
        $class = array( trim( $extra_class ) );
        switch ( $sidebar_pos )
        {
            case 'left':
                $class[] = 'col-lg-8 order-lg-2';
                break;

            case 'right':
                $class[] = 'col-lg-8';
                break;

            default:
                $class[] = 'col-lg-12';
			break;
        }

        $class = implode( ' ', array_filter( $class ) );

        if ( $class ) {
            echo ' class="' . esc_html($class) . '"';
        }
    } else {
        echo ' class="posts"'; 
    }
}

/**
 * Set secondary content class based on sidebar position
 * 
 * @param  string $sidebar_pos
 * @param  string $extra_class
 */
function gymnaz_secondary_class( $sidebar_pos, $extra_class = '' )
{
    if (is_page()) :
        $sidebar_load = 'sidebar';
    else :
        $sidebar_load = 'sidebar';
    endif;

    if ( is_active_sidebar( $sidebar_load ) ) {
        $class = array(trim($extra_class));
        switch ($sidebar_pos) {
            case 'left':
                $class[] = 'col-lg-4 order-lg-1';
                break;

            case 'right':
                $class[] = 'col-lg-4';
                break;

			default:
				$class[] = 'col-lg-4';
				break;
        }

        $class = implode(' ', array_filter($class));

        if ($class) {
            echo ' class="' . esc_html($class) . '"';
        }
    }	
}




/**
 * Prints archive meta on blog
 */
if ( ! function_exists( 'gymnaz_archive_meta' ) ) :
    function gymnaz_archive_meta() {
        $archive_comments_on = gymnaz_get_opt( 'archive_comments_on', true );
		$archive_author_on = gymnaz_get_opt( 'archive_author_on', true );
		$archive_views_on = gymnaz_get_opt( 'archive_views_on', true );
        if( $archive_author_on || $archive_comments_on || $archive_views_on ) : ?>
        	<ul class="post-meta">
	            <?php if($archive_author_on) : ?>
	                <li>
	                    <i class="fa fa-user"></i>
	                    <a href="<?php echo esc_url(get_author_posts_url(get_the_author_meta('ID')),'gymnaz-pro'); ?>"><?php the_author(); ?></a>
	                </li>
	            <?php endif; ?>
	            <?php if($archive_comments_on) : ?>
	                <li>
	                    <i class="fa fa-comments"></i>
	                    <a href="#"><?php comments_number( __('0', 'gymnaz-pro' ), __('1', 'gymnaz-pro' ), __('%', 'gymnaz-pro' ) ); ?></a>
	                </li>
	            <?php endif; ?>
	            <?php if($archive_views_on) : ?>
	            <li>
	                <i class="fa fa-eye"></i>
	                <a href="#"><?php  echo getPostViews(get_the_ID()); ?></a>
	            </li>
	            <?php endif; ?>
	        </ul>
			
    <?php endif; }
endif;

/**
 * Prints post meta on blog
 */
if ( ! function_exists( 'gymnaz_post_meta' ) ) :
    function gymnaz_post_meta() {
		$post_an_on = gymnaz_get_opt( 'post_an_on', true );
        $post_comments_on = gymnaz_get_opt( 'post_comments_on', false );
		$post_date_on = gymnaz_get_opt( 'post_date_on', false );
        if( $post_an_on || $post_comments_on || $post_date_on) : ?>
        	<ul class="post-meta text-left">
                <?php if($post_an_on) : ?>
                    <li>
                        <i class="fa fa-user"></i>
                        <a href="<?php echo esc_url(get_author_posts_url(get_the_author_meta('ID')),'gymnaz-pro'); ?>"><?php the_author(); ?></a>
                    </li>
                <?php endif; ?>
                <?php if($post_comments_on) : ?>
                    <li>
                        <i class="fa fa-comments"></i>
                        <a href="#"><?php comments_number( __('0 Comment', 'gymnaz-pro' ), __('1 Comment', 'gymnaz-pro' ), __('% Comments', 'gymnaz-pro' ) ); ?></a>
                    </li>
                <?php endif; ?>
                <?php if($post_date_on) : ?>
                    <li>
                        <i class="fa fa-calendar"></i>
                        <?php the_date(); ?>
                    </li>
                <?php endif; ?>
            </ul>
	    <?php endif; 
	}
endif;



/**
 * List socials share for post.
 */
function gymnaz_socials_share_default() { ?>
	<div class="blog-socials py-2 my-1 d-flex">
        <p class="text-capitalize mr-2 mb-0">
            <i class="fa fa-share-alt mr-2 c-theme"></i> <?php esc_html_e('share :','gymnaz-pro') ?>
        </p>
        <div class="share jssocials">
	        <div class="jssocials-share jssocials-share-linkedin">
	        	<a title="Facebook" target="_blank" href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>" ><i class="fa fa-facebook-square"></i></a>
	        </div>
	        <div class="jssocials-share jssocials-share-linkedin">
				<a title="Twitter" target="_blank" href="https://twitter.com/home?status=<?php the_permalink(); ?>"><i class="fa fa-twitter-square"></i></a>
			</div>
			<div class="jssocials-share jssocials-share-linkedin">
				<a title="Google Plus" target="_blank" href="https://plus.google.com/share?url=<?php the_permalink(); ?>"><i class="fa fa-google-plus-square"></i></a>
			</div>
			<div class="jssocials-share jssocials-share-linkedin">
				<a title="Linkedin" target="_blank" href="https://www.linkedin.com/shareArticle?mini=true&url=<?php the_permalink(); ?>"><i class="fa fa-linkedin-square"></i></a>
			</div>
		</div>
       
    </div>
<?php } ?>