<?php

/**
 * Gymnaz Theme Setup and definitions
 * @package Gymnaz
 */

if ( ! function_exists( 'gymnaz_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function gymnaz_setup() {

		define( 'no_image', THEME_URI . '/assets/img/no-image-thumb.jpg');

		// Make theme available for translation.
		load_theme_textdomain( 'gymnaz-pro', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Let WordPress manage the document title.
		add_theme_support( 'title-tag' );

		// Enable support for Post Thumbnails on posts and pages.
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'gymnaz-pro' ),
			'left' => esc_html__( 'Left Side Menu', 'gymnaz-pro' ),
			'right' => esc_html__( 'Right Side Menu', 'gymnaz-pro' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'gymnaz_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		/* Change default image thumbnail sizes in wordpress */
		update_option('thumbnail_size_w', 300);
		update_option('thumbnail_size_h', 300);
		update_option('thumbnail_crop', 1);
		update_option('medium_size_w', 455);
		update_option('medium_size_h', 410);
		update_option('medium_crop', 1);
		update_option('large_size_w', 980);
		update_option('large_size_h', 590);
		update_option('large_crop', 1);
		
	}
endif;
add_action( 'after_setup_theme', 'gymnaz_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function gymnaz_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'gymnaz_content_width', 640 );
}
add_action( 'after_setup_theme', 'gymnaz_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function gymnaz_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar Blog', 'gymnaz-pro' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'gymnaz-pro' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="title-sep2 mb-30">',
		'after_title'   => '</h4>',
	) );

	// Wigets for portfolio style 
	register_sidebar( array(
		'name'          => esc_html__( 'Portfolio Sidebar', 'gymnaz-pro' ),
		'id'            => 'portfolio_sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'gymnaz-pro' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="title-sep2 mb-30">',
		'after_title'   => '</h4>',
	) );

	// Wigets for footer style 
	register_sidebar(array(
		'name' => __( 'Footer Column 1', 'gymnaz-pro'),
		'id' => 'gymnaz-footer1',
		'description' => __( 'Footer widget', 'gymnaz-pro'),
		'before_widget' => '<div id="%1$s" class="%2$s widget">',
		'after_widget' => '</div>',
		'before_title' => '<div class="foot-title"><h4>',
		'after_title' => '</h4></div>',
	));	

	register_sidebar(array(
		'name' => __( 'Footer Column 2', 'gymnaz-pro'),
		'id' => 'gymnaz-footer2',
		'description' => __( 'Footer widget', 'gymnaz-pro'),
		'before_widget' => '<div id="%1$s" class="%2$s widget">',
		'after_widget' => '</div>',
		'before_title' => '<div class="foot-title"><h4>',
		'after_title' => '</h4></div>',
	));	

	register_sidebar(array(
		'name' => __( 'Footer Column 3', 'gymnaz-pro'),
		'id' => 'gymnaz-footer3',
		'description' => __( 'Footer widget', 'gymnaz-pro'),
		'before_widget' => '<div id="%1$s" class="%2$s widget">',
		'after_widget' => '</div>',
		'before_title' => '<div class="foot-title"><h4>',
		'after_title' => '</h4></div>',
	));	
	register_sidebar(array(
		'name' => __( 'Footer Column 4', 'gymnaz-pro'),
		'id' => 'gymnaz-footer4',
		'description' => __( 'Footer widget', 'gymnaz-pro'),
		'before_widget' => '<div id="%1$s" class="%2$s widget">',
		'after_widget' => '</div>',
		'before_title' => '<div class="foot-title"><h4>',
		'after_title' => '</h4></div>',
	));	
}
add_action( 'widgets_init', 'gymnaz_widgets_init' );

/**
 * Enqueue scripts and styles.
*/
function gymnaz_scripts() {

	$theme = wp_get_theme(get_template());
    // CSS Files
    wp_enqueue_style(   'Roboto',      					gymnaz_fonts_url() ); 
    wp_enqueue_style(   'gymnaz-pro' . '-plugin',     		ASSETS . '/css/plugins.css' ); 
	wp_enqueue_style(   'style-template',      			ASSETS . '/css/style.css' );
	wp_enqueue_style(   'gymnaz-pro' . '-responsive',      	ASSETS . '/css/responsive.css' ); 
	// REVOLUTION STYLE SHEETS
	wp_enqueue_style('revolution-settings', 			ASSETS . '/revolution/revolution/css/settings.css');
	// REVOLUTION LAYERS STYLES
	wp_enqueue_style('revolution-layers', 				ASSETS . '/revolution/revolution/css/layers.css');
	// REVOLUTION NAVIGATION STYLES
	wp_enqueue_style('revolution-navigation', 			ASSETS . '/revolution/revolution/css/navigation.css');
	// PARTICLES ADD-ON FILES
	wp_enqueue_style('revolution-particles', 			ASSETS . '/css/rev-slider.css');
	wp_enqueue_style('revolution-addon', 			    ASSETS . '/revolution/revolution-addons/particles/css/revolution.addon.particles.css?ver=1.0.3');
    wp_enqueue_style(   'gymnaz-style',      			 get_stylesheet_uri() ); 
	
	
	// JS Files    
	
	
	wp_enqueue_script(  'popper', 						ASSETS . '/js/popper.min.js','', 'all', true );
    wp_enqueue_script( 	'bootstrap-js', 				ASSETS . '/js/bootstrap.min.js', array( 'jquery' ), 'all', true );
    wp_enqueue_script(  'owl-carousel-js', 				ASSETS . '/js/owl.carousel.min.js', array( 'jquery' ), 'all', true );
    wp_enqueue_script(  'owl-custom-js', 				ASSETS . '/js/swiper.min.js', array( 'jquery' ), 'all', true );
	wp_enqueue_script(  'navigation', 					ASSETS . '/js/lity.min.js', array( 'jquery' ), 'all', true );
	wp_enqueue_script(  'isotope', 						ASSETS . '/js/isotope.min.js', array( 'jquery' ), 'all', true );
	wp_enqueue_script(  'magnific', 					ASSETS . '/js/jquery.magnific-popup.min.js', array( 'jquery' ), 'all', true );
    wp_enqueue_script(  'gymnaz-pro' . '-custom',  			ASSETS . '/js/custom.js', array( 'jquery' ), 'all', true );
    
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_localize_script('gymnaz-main-ajax','main_data',array('ajax_url'=>admin_url('admin-ajax.php')));
	
	
	// REVOLUTION JS FILES	
	wp_enqueue_script('themepunch-tools', 					ASSETS . '/revolution/revolution/js/jquery.themepunch.tools.min.js', array('jquery'), $theme->get('Version'), true );
	wp_enqueue_script('themepunch-revolution', 			ASSETS . '/revolution/revolution/js/jquery.themepunch.revolution.min.js', array('jquery'), $theme->get('Version'), true );

	//PARTICLES ADD-ON FILES
	wp_enqueue_script('themepunch-addon', 			ASSETS . '/revolution/revolution-addons/particles/js/revolution.addon.particles.min.js?ver=1.0.3', array('jquery'), $theme->get('Version'), true );
	
	
	// SLIDER REVOLUTION 5.0 EXTENSIONS  (Load Extensions only on Local File Systems !  The following part can be removed on Server for On Demand Loading)
	wp_enqueue_script('revolution-ext-actions', 			ASSETS . '/revolution/revolution/js/extensions/revolution.extension.actions.min.js', array('jquery'), $theme->get('Version'), true );
	wp_enqueue_script('revolution-ext-carousel', 		ASSETS . '/revolution/revolution/js/extensions/revolution.extension.carousel.min.js', array('jquery'), $theme->get('Version'), true );
	wp_enqueue_script('revolution-ext-kenburn', 		ASSETS . '/revolution/revolution/js/extensions/revolution.extension.kenburn.min.js', array('jquery'), $theme->get('Version'), true );
	wp_enqueue_script('revolution-ext-layeranimation', 	ASSETS . '/revolution/revolution/js/extensions/revolution.extension.layeranimation.min.js', array('jquery'), $theme->get('Version'), true );
	wp_enqueue_script('revolution-ext-migration', 		ASSETS . '/revolution/revolution/js/extensions/revolution.extension.migration.min.js', array('jquery'), $theme->get('Version'), true );
	wp_enqueue_script('revolution-ext-navigation', 		ASSETS . '/revolution/revolution/js/extensions/revolution.extension.navigation.min.js', array('jquery'), $theme->get('Version'), true );
	wp_enqueue_script('revolution-ext-parallax', 			ASSETS . '/revolution/revolution/js/extensions/revolution.extension.parallax.min.js', array('jquery'), $theme->get('Version'), true );
	wp_enqueue_script('revolution-ext-slideanims', 		ASSETS . '/revolution/revolution/js/extensions/revolution.extension.slideanims.min.js', array('jquery'), $theme->get('Version'), true );
	wp_enqueue_script('revolution-ext-video', 		ASSETS . '/revolution/revolution/js/extensions/revolution.extension.video.min.js', array('jquery'), $theme->get('Version'), true );
	wp_enqueue_script('revolution-ext-rev-slider', 		ASSETS . '/js/rev-slider.js', array(), $theme->get('Version'), true );


	if(gymnaz_get_opt( 'show_page_loading', false )){
		// Initialize preloader
		$preloader_js = 'jQuery(".js-preloader").preloadinator({ minTime: 2000 });';
		wp_add_inline_script('gymnaz-custom', $preloader_js);
	}

}
add_action( 'wp_enqueue_scripts', 'gymnaz_scripts' );

// add ie conditional html5 shim to header
function add_ie_html5_shim () {
    echo '<!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->';
    echo "<!-- WARNING: Respond.js doesn't work if you view the page via file:// -->";
    echo '<!--[if lt IE 9]>';
    echo '<script src="https://oss.maxcdn.com/html5shiv/3.7.3/html5shiv.min.js"></script>';
    echo '<script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>';
    echo '<![endif]-->';
}
add_action('wp_head', 'add_ie_html5_shim', 100 );


/* add admin styles */
function gymnaz_admin_style() {
	wp_enqueue_style('gymnaz-style', get_template_directory_uri() . '/assets/css/gym-meta.css');
	wp_enqueue_style(   'gymnaz-pro' . '-flaticon', get_template_directory_uri() . '/assets/css/flaticon.css' ); 
	wp_enqueue_style('gymnaz-admin-style', get_template_directory_uri() . '/assets/css/admin.css');
	wp_enqueue_style('gymnaz-icon-picker', get_template_directory_uri() . '/assets/css/icon-picker/icon-picker.css');
	wp_enqueue_script('gymnaz_icon_picker', get_template_directory_uri() .'/assets/js/icon-picker/icon-picker.js', array(), time(), true);
}

add_action('admin_enqueue_scripts', 'gymnaz_admin_style');

if ( ! function_exists( 'gymnaz_fonts_url' ) ) :
    /**
     * Register Google fonts.
     *
     * Create your own gymnaz_fonts_url() function to override in a child theme.
     *
     * @since league 1.1
     *
     * @return string Google fonts URL for the theme.
     */
    function gymnaz_fonts_url()
    {
        $fonts_url = '';
        $fonts     = array();
        $subsets   = 'latin,latin-ext';

        if ( 'off' !== _x( 'on', 'Roboto font: on or off', 'gymnaz-pro' ) )
        {
            $fonts[] = 'Roboto:300,400,500,700,900';
        }

        if ( 'off' !== _x( 'on', 'Open Sans font: on or off', 'gymnaz-pro' ) )
        {
            $fonts[] = 'Open Sans:400,600,700,800';
        }

        if ( $fonts ) {
            $fonts_url = add_query_arg( array(
                'family' => urlencode( implode( '|', $fonts ) ),
                'subset' => urlencode( $subsets ),
            ), 'https://fonts.googleapis.com/css' );
        }

        return $fonts_url;
    }
endif;